pub fn run_program(
user_key: &mut String,
world: &mut Tree<String, Vessel>,
program: Vec<Action>,
) -> Result<ActionResult, Box<dyn Error>>Expand description
Runs the provided program on the provided world-state, possibly modifying the provided user key.
user_key: The key of the user’s active Vessel.world: The mutable world-state.program: The set of Actions to be run.
Returns an ActionResult informing the client of what to tell the user, if successful.
Errors:
This method fails if any of the Actions fails.