Action

Enum Action 

pub enum Action {
Show 19 variants Create(VesselRequest), Become(VesselRequest), Enter(VesselRequest), Leave, Take(VesselRequest), Drop(VesselRequest), Move { object_article: Option<Article>, object_name: String, preposition: IntoPrep, target_article: Option<Article>, target_name: String, }, Look { preposition: Option<AtPrep>, basic: Option<VesselRequest>, }, Transform { preposition: Option<IntoPrep>, basic: VesselRequest, }, Note { text: Option<String>, }, Warp { preposition: Option<IntoPrep>, basic: VesselRequest, }, Program(Option<VesselRequest>), Use(VesselRequest), Cast { spell: VesselRequest, preposition: OnPrep, target: VesselRequest, }, Save { filename: Option<String>, }, Load { filename: Option<String>, }, Debug, Exit, Learn { preposition: Option<AboutPrep>, topic: Option<Verb>, },
}
An action to be executed by the system interface.

Variants



Create(VesselRequest)

Creates a new vessel adjacent to the user’s.



Become(VesselRequest)

Takes control of an adjacent vessel.



Enter(VesselRequest)

Moves the controlled vessel into an adjacent vessel.



Leave

Moves the controlled vessel out of its parent, into its parent’s parent.



Take(VesselRequest)

Moves an adjacent vessel into the controlled vessel.



Drop(VesselRequest)

Moves a vessel inside the controlled vessel into the controlled vessel’s parent.



Move

Moves an adjacent vessel into another adjacent vessel.

Fields

object_article: Option<Article>

The optional Article with which to refer to the object being moved.

object_name: String

The name/key of the object being moved.

preposition: IntoPrep

The preposition separating the two crate::vessel::Vessels.

target_article: Option<Article>

The optional Article with which to refer to the target being moved to.

target_name: String

The name/key of the target being moved to.



Look

Displays a list of the adjacent vessels, or of the vessels inside an adjacent vessel.

Fields

preposition: Option<AtPrep>

An optional preposition before the crate::vessel::Vessel being specified.

basic: Option<VesselRequest>

An optional set of identifiers for a crate::vessel::Vessel to look at/inside.



Transform

Renames the controlled vessel.

Fields

preposition: Option<IntoPrep>

An optional preposition before the crate::vessel::Vessel being specified.

basic: VesselRequest

A set of identifiers for the crate::vessel::Vessel’s new name and Article.



Note

Assigns a description to the parent of the controlled vessel.

Fields

text: Option<String>

The description text, to which the note will be set.



Warp

Moves the controlled vessel into another vessel, regardless of adjacency.

Fields

preposition: Option<IntoPrep>

An optional preposition before the crate::vessel::Vessel being specified.

basic: VesselRequest

A set of identifiers for the crate::vessel::Vessel being moved to.



Program(Option<VesselRequest>)

Begins programming a task for an adjacent vessel.



Use(VesselRequest)

Executes an adjacent vessel’s program.



Cast

Executes a distant vessel’s program as another vessel.

Fields

spell: VesselRequest

A set of identifiers for the crate::vessel::Vessel whose program should be run.

preposition: OnPrep

The preposition separating the two crate::vessel::Vessels.

target: VesselRequest

A set of identifiers for the crate::vessel::Vessel for the program to run as.



Save

Saves the state of all vessels to a file.

Fields

filename: Option<String>

The name of the file to be saved to.



Load

Loads the state of all vessels from a file.

Fields

filename: Option<String>

The name of the file to be loaded from.



Debug

Displays the state of all vessels as raw json data.



Exit

Exits parade, or stops programming a vessel if the user is doing so.



Learn

Displays general information on Parade, or information on a specific action.

Fields

preposition: Option<AboutPrep>

An optional preposition before the help topic being specified.

topic: Option<Verb>

The optional help topic, to have its Verb::help_text displayed.

Implementations

Source

impl Action

pub fn from_vessel_request( verb: Verb, basic: VesselRequest, ) -> Result<Self, Error>

Wraps a VesselRequest in an Action, if the Verb refers to an Action that wraps a VesselRequest.

Errors

This method fails if the Verb refers to an Action which does not exclusively wrap a VesselRequest. The viable Verbs are:

pub fn parse(action_string: &str) -> Result<Option<Action>, Error>

Parse a user-provided action string into an Action (or none, if the user entered nothing).

Errors

This method fails if the string does not match the requirements of the given Action, or specifies a Verb which does not exist.