pub enum Error {
MissingNoun,
MissingSecondNoun,
UnknownVerb(String),
NonBasicAction(Verb),
}Expand description
The errors that can be encountered when parsing an Action.
Variants
MissingNoun
Occurs when the Action requires a noun, but none is provided.
MissingSecondNoun
Occurs when the Action requires two nouns, but only one is provided.
UnknownVerb(String)
Occurs when the input does not match any Verb.
NonBasicAction(Verb)
Occurs when the system attempts to wrap a VesselRequest with an Action variant that does not support it.