Verb

Enum Verb 

pub enum Verb {
Show 19 variants Learn, Create, Become, Enter, Leave, Take, Drop, Move, Look, Transform, Note, Warp, Program, Use, Cast, Exit, Save, Load, Debug,
}
The name of an Action, for use in parsing and help messages.

Variants



Learn

Displays general information on Parade, or information on a specific action or topic.



Create

Creates a new vessel adjacent to the user’s.



Become

Takes control of an adjacent vessel.



Enter

Moves the controlled vessel into an adjacent vessel.



Leave

Moves the controlled vessel out of its parent, into its parent’s parent.



Take

Moves an adjacent vessel into the controlled vessel.



Drop

Moves a vessel inside the controlled vessel into the controlled vessel’s parent.



Move

Moves an adjacent vessel into another adjacent vessel.



Look

Displays a list of the adjacent vessels, or of the vessels inside an adjacent vessel.



Transform

Renames the controlled vessel.



Note

Assigns a description to the parent of the controlled vessel.



Warp

Moves the controlled vessel into another vessel, regardless of adjacency.



Program

Begins programming a task for an adjacent vessel.



Use

Executes an adjacent vessel’s program.



Cast

Executes a distant vessel’s program as another vessel.



Exit

Exits parade, or stops programming a vessel if the user is doing so.



Save

Saves the state of all vessels to a file.



Load

Loads the state of all vessels from a file.



Debug

Displays the state of all vessels as raw json data.

Implementations

Source

impl Verb

pub fn short_help_text(&self) -> String

Returns the short help text for the given Verb.

pub fn help_text(&self) -> String

Returns the long help text for the given Verb.

pub fn help_list_text() -> String

Returns the a basic help message, alongside the Self::short_help_text for every Verb.