pub struct VesselRequest {
pub article: Option<Article>,
pub name: String,
}Expand description
A basic set of Action parameters, indicating a crate::vessel::Vessel by name and (optionally) Article.
Fields
article: Option<Article>The Article with which to refer to the crate::vessel::Vessel.
name: StringThe name/key of the crate::vessel::Vessel being indicated.
Implementations
Sourceimpl VesselRequest
impl VesselRequest
Sourcepub fn parse<'a, T: Iterator<Item = &'a str>>(
second_word: &'a str,
words: &mut T,
) -> Result<Self, Error>
pub fn parse<'a, T: Iterator<Item = &'a str>>( second_word: &'a str, words: &mut T, ) -> Result<Self, Error>
Parses a VesselRequest from the given second and following words of an action string. (The first word is always the Verb.)
Sourcepub fn parse_with_prep<'a, P: Preposition, T: Iterator<Item = &'a str>>(
second_word: &'a str,
words: &mut T,
) -> Result<(Option<P>, Self), Error>
pub fn parse_with_prep<'a, P: Preposition, T: Iterator<Item = &'a str>>( second_word: &'a str, words: &mut T, ) -> Result<(Option<P>, Self), Error>
Parses a VesselRequest and optional Preposition from the given second and following words of an action string. (The first word is always the Verb.)